@@ -15,6 +15,9 @@
 
 namespace clang {
 
+/// DependencyOutputFormat - Format for the compiler dependency file.
+enum class DependencyOutputFormat { Make, NMake };
+
 /// DependencyOutputOptions - Options for controlling the compiler dependency
 /// file generation.
 class DependencyOutputOptions {
@@ -27,7 +30,10 @@ public:
   unsigned AddMissingHeaderDeps : 1; ///< Add missing headers to dependency list
   unsigned PrintShowIncludes : 1; ///< Print cl.exe style /showIncludes info.
   unsigned IncludeModuleFiles : 1; ///< Include module file dependencies.
-  
+
+  /// The format for the dependency file.
+  DependencyOutputFormat OutputFormat;
+
   /// The file to write dependency output to.
   std::string OutputFile;
 
@@ -55,6 +61,7 @@ public:
     AddMissingHeaderDeps = 0;
     PrintShowIncludes = 0;
     IncludeModuleFiles = 0;
+    OutputFormat = DependencyOutputFormat::Make;
   }
 };
 
